/* learn step boundaries;*/

data electric;
length customer $12. ;
informat revenue dollar10.; 
input customer $ revenue year @@;
datalines;
Commercial $63 1994 
Industrial $48 1994 
Other $7 1994 
Residential $85 1994 
Commercial $66 1995 
Industrial $47 1995 
Other $7 1995 
Residential $88 1995 
Commercial $68 1996 
Industrial $48 1996 
Other $7 1996 
Residential $91 1996 
Commercial $70 1997 
Industrial $47 1997 
Other $7 1997 
Residential $91 1997 
Commercial $73 1998 
Industrial $47 1998 
Other $7 1998 
Residential $93 1998 
Commercial $73 1999 
Industrial $47 1999 
Other $7 1999 
Residential $93 1999 
Commercial $78 2000 
Industrial $49 2000 
Other $7 2000 
Residential $98 2000 
Commercial $86 2001 
Industrial $50 2001 
Other $8 2001 
Residential $103 2001 
Commercial $87 2002 
Industrial $48 2002 
Other $7 2002 
Residential $107 2002 
Commercial $96 2003 
Industrial $52 2003 
Other $1 2003 
Residential $111 2003 
Commercial $101 2004 
Industrial $53 2004 
Other $1 2004 
Residential $116 2004 
Commercial $111 2005 
Industrial $58 2005 
Other $1 2005 
Residential $128 2005 
;
run;

PROC MEANS data = electric;
    class customer ;
	var revenue;
run;

PROC PRINT DATA=electric;
          VAR customer revenue year;
          FORMAT revenue DOLLAR10.;
RUN;                 

PROC IMPORT DATAFILE = 'd:\sasworkshop\data\electric.xls' DBMS=XLS OUT = electric0;
RUN;

/* Step1: Create the format for certain variables */    
PROC FORMAT;
    VALUE revfmt
       low-<50='Less than 50'
       50 - high='50 and above' ;  
    VALUE $cstmFmt
       'Commercial' = 'Commercial'
       'Industrial' = 'Others'
       'Residential' = 'Others'
       'Other' = 'Others';
RUN;

/* Step2: Assign the variables */
DATA electricformat;
  SET electric;
  FORMAT  revenue revfmt. Customer cstmfmt.;
RUN;

PROC PRINT DATA = electricformat;
TITLE 'Electric Data Set formatted'; RUN;

libname readdata 'd:\sasworkshop\sasdata';  
data readdata.electric;
set electric0;
run;

Title "";

proc print data = sashelp.electric noobs;
var customer revenue year;
run;

proc freq data = sashelp.electric;
table customer*revenue/norow nocol;
FORMAT  revenue revfmt.;
format Customer $cstmfmt.;
run;

proc ttest data=sashelp.class alpha=.05;
class sex;
var height;
run;

proc reg data = sashelp.electric(
     where=(customer="Residential"));
model coal= year;
run;

proc corr data= sashelp.electric(
     where=(customer="Residential"));
var coal year;
run;
title ' ';
ods listing style =journal;
proc sgplot data=sashelp.electric(
     where=(customer="Residential"));
  xaxis type=discrete;
  series x=year y=coal;
  series x=year y=naturalgas / y2axis;
run;

proc tabulate data=electric;
class year customer;
table year all, customer all;
format customer $cstmfmt.;
run;

proc tabulate data=electric;
class customer;
var revenue;
table customer all, revenue*(n mean sum);
run;


proc tabulate data=electric;
class year;
var revenue;
table year all, revenue*(n mean sum);
run;


/************************************************************************/
/************** Macros Usage (Example)**********************************/
/************************************************************************/

%macro sumreport(dataset, clsvar, avar);
DATA _NULL_;
 SET &dataset END =eof;
 IF eof THEN CALL SYMPUT('nobs', trim(left(_N_)));
RUN; 

ods pdf file = "d:\sasworkshop\output\&dataset.report&sysdate..pdf";
proc tabulate data=&dataset.;
class &clsvar.;
var &avar.;
table &clsvar., &avar.*(n mean sum);
title "Summary of &dataset. &avar. (N=&nobs)";
run;
ods pdf close;
%mend;

%sumreport(electric, customer, revenue);






